@@ -1,7 +1,7 @@
 package Net::OpenStack::Compute;
 use Moo;
 
-our $VERSION = '1.1000'; # VERSION
+our $VERSION = '1.1001'; # VERSION
 
 use Carp;
 use HTTP::Request;
@@ -244,7 +244,7 @@ sub _check_res {
     return 1;
 }
 
-around [qw( _get _post _delete )] => sub {
+my $around_sub = sub {
     my $orig = shift;
     my $self = shift;
     my $res = $self->$orig(@_);
@@ -252,6 +252,11 @@ around [qw( _get _post _delete )] => sub {
     return $res;
 };
 
+
+for my $s (qw( _get _post _delete )) {
+    around $s => $around_sub;
+}
+
 # ABSTRACT: Bindings for the OpenStack Compute API.
 
 
@@ -266,7 +271,7 @@ Net::OpenStack::Compute - Bindings for the OpenStack Compute API.
 
 =head1 VERSION
 
-version 1.1000
+version 1.1001
 
 =head1 SYNOPSIS
 
